@@ -16,6 +16,16 @@ umount_path = "/bin/umount"
 def partition(dev):
     """Partition an empty disk drive to have exactly 1 partition
     on it filling the whole space."""
+
+    # TODO: this is a hack for now; figure out if there's a better way
+    # to test if a disk has been partitioned.  Two known alternatives:
+    #
+    # 1. parse `parted -lm` output
+    # 2. investigate not-super-publicly-accessible `pyparted` RedHat package
+
+    if os.path.exists(dev + "1"): #e.g. /dev/sdb -> /dev/sdb1
+        return None
+
     cmd = [sgdisk_path, dev, "-N", str(1)]
     status = subprocess.call(cmd, stdout=sys.stdout, stderr=sys.stderr)
     return status
@@ -78,9 +88,22 @@ def _set_mount(fstab_in, args_in):
     return "".join([' '.join(l) + "\n" for l in lines])
 
 def set_mount(args_in):
+    """Sets up a mount in /etc/fstab
+
+    Takes a dict of arguments:
+
+       {'src': '/dev/sda1', # the device
+        'name': '/tmp',     # where to mount the device
+        'fstype': 'ext3',   # filesystem type
+        'opts': 'defaults', # OPTIONAL mount opts, as a string
+        'dump': '0',        # OPTIONAL dump, as a string
+        'passno': '0',      # OPTIONAL passno, as a string
+       }
+    """
     with open("/etc/fstab", 'r') as f:
         input = f.read()
         output = _set_mount(input, args_in)
+
     with open("/etc/fstab", 'w') as f:
         f.write(output)
 
